Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // SnapshotCreatePath defines vmstorage endpoint to create instant snapshot SnapshotCreatePath = "/snapshot/create" // SnapshotDeleteAll defines vmstorage endpoint to delete all snapshots SnapshotDeleteAll = "/snapshot/delete_all" )
Functions ¶
This section is empty.
Types ¶
type SnapClient ¶
type SnapClient struct {
// contains filtered or unexported fields
}
func New ¶
func New(host string, port uint16, proto string) *SnapClient
New creates an instance of SnapClient
func (SnapClient) ComposeBasePath ¶
func (c SnapClient) ComposeBasePath() string
func (SnapClient) CreateSnapshot ¶
func (c SnapClient) CreateSnapshot() (*SnapResponse, error)
func (SnapClient) DeleteAllSnaps ¶
func (c SnapClient) DeleteAllSnaps() (*SnapResponse, error)
type SnapResponse ¶
Click to show internal directories.
Click to hide internal directories.